/*******************************************************************************
* Title                 :   Interrupt Service Routines
* Filename              :   isr.c
* Author                :   JWB
* Origin Date           :   04/1/2015
* Version               :   1.0.0
* Compiler              :   COMPILER GOES HERE
* Target                :   MCU TARGET GOES HERE
* Notes                 :   None
*
* THIS SOFTWARE IS PROVIDED BY BENINGO ENGINEERING "AS IS" AND ANY EXPRESSED
* OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL BENINGO ENGINEERING OR ITS CONTRIBUTORS BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
* STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
* IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
* THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************/
/****************************************************************************
* Doxygen C Template
* Copyright (c) 2013 - Jacob Beningo - All Rights Reserved
*
* Feel free to use this Doxygen Code Template at your own risk for your own
* purposes.  The latest license and updates for this Doxygen C template can be  
* found at www.beningo.com or by contacting Jacob at jacob@beningo.com.
*
* For updates, free software, training and to stay up to date on the latest 
* embedded software techniques sign-up for Jacobs newsletter at 
* http://www.beningo.com/814-2/
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Template. 
*
*****************************************************************************/
/*************** MODULE REVISION LOG ******************************************
*
*    Date    Version    Author             Description 
*  04/01/15   1.0.0   Jacob Beningo      Module Created.
*  04/28/15   1.0.1   Jacob Beningo      Updated to match interface changes
*                                        Doxygen errors resolved in comments
*
*******************************************************************************/
/** @file isr.c
 *  @brief This module contains functions for controlling interrupts 
 */
/******************************************************************************
* Includes
*******************************************************************************/
#include "isr.h"		// For this modules defintions

/******************************************************************************
* Module Preprocessor Constants
*******************************************************************************/

/******************************************************************************
* Module Preprocessor Macros
*******************************************************************************/

/******************************************************************************
* Module Typedefs
*******************************************************************************/

/******************************************************************************
* Module Variable Definitions
*******************************************************************************/
/**
 * Stores the state of global interrupts.  They can be enabled or disabled
 */
 static IsrState_t IsrState = ISR_DISABLED;

/******************************************************************************
* Function Prototypes
*******************************************************************************/

/******************************************************************************
* Function Definitions
*******************************************************************************/
/******************************************************************************
* Function : Isr_Enable()
*//** 
* \b Description:
*
*  This function is used to enable individual interrupts 
*
* @param  		IsrIndex      The index of the ISR that will be enabled
*
* @return 		void
*
* @see Isr_Disable
* @see Isr_Enable
* @see Isr_GlobalStateSet
* @see Isr_GlobalStateGet
* @see Isr_CriticalSectionStart
* @see Isr_CriticalSectionEnd
*
* \b Example Example:
* @code
*    Isr_Enable(Isr_Uart0);
* @endcode
*
*  ----------------------
*  - HISTORY OF CHANGES -
*  ----------------------
*    Date    Software Version    Initials   Description 
*  04/01/15       1.0.0            JWB      Function Created.
*
*******************************************************************************/
void Isr_Enable(Isr_t IsrIndex)
{
   // TODO:
   // Single ISR enable code goes here
   // TARGET CODE GOES HERE
}

/******************************************************************************
* Function : Isr_Disable()
*//** 
* \b Description:
*
*  This function is used to disable individual interrupts 
*
* @param  		IsrIndex      The index of the ISR that will be enabled
*
* @return 		void
*
* @see Isr_Disable
* @see Isr_Enable
* @see Isr_GlobalStateSet
* @see Isr_GlobalStateGet
* @see Isr_CriticalSectionStart
* @see Isr_CriticalSectionEnd
*
* \b Example Example:
* @code
*    Isr_Disable(Isr_Uart0);
* @endcode
*
*  ----------------------
*  - HISTORY OF CHANGES -
*  ----------------------
*    Date    Software Version    Initials   Description 
*  04/01/15       1.0.0            JWB      Function Created.
*  04/28/15       1.0.1            JWB      Added parameter variable
*******************************************************************************/
void Isr_Disable(Isr_t IsrIndex)
{
   // TODO:
   // Single ISR disable code goes here
   // TARGET CODE GOES HERE
}

/******************************************************************************
* Function : Isr_GlobalEnable()
*//** 
* \b Description:
*
*  This function is used to enable global interrupts 
*
* @return 		void
*
* @see Isr_Disable
* @see Isr_Enable
* @see Isr_GlobalStateSet
* @see Isr_GlobalStateGet
* @see Isr_CriticalSectionStart
* @see Isr_CriticalSectionEnd
*
* \b Example Example:
* @code
*    Isr_GlobalStateSet(ISR_ENABLED);
* @endcode
*
*  ----------------------
*  - HISTORY OF CHANGES -
*  ----------------------
*    Date    Software Version    Initials   Description 
*  04/01/15       1.0.0            JWB      Function Created.
*
*******************************************************************************/
void Isr_GlobalStateSet(IsrState_t State);
{
   // TODO:
   // Global ISR enable code goes here
   // TARGET CODE GOES HERE

   // Save the global state so that it can be restored after a critical section	
   IsrState = ISR_ENABLED;
}

/******************************************************************************
* Function : Isr_GlobalStateGet()
*//** 
* \b Description:
*
*  This function is used to retrieve the state of the global interrupts. 
*
* @return 		IsrState_t  The state of the global interrupts
*
* @see Isr_Disable
* @see Isr_Enable
* @see Isr_GlobalStateSet
* @see Isr_GlobalStateGet
* @see Isr_CriticalSectionStart
* @see Isr_CriticalSectionEnd
*
* \b Example Example:
* @code
*     IsrState;
*
*    IsrState = Isr_GlobalStateGet();
* @endcode
*
*  ----------------------
*  - HISTORY OF CHANGES -
*  ----------------------
*    Date    Software Version    Initials   Description 
*  04/01/15       1.0.0            JWB      Function Created.
*
*******************************************************************************/
IsrState_t Isr_GlobalStateGet(void)
{
   return IsrState;
}

/******************************************************************************
* Function : Isr_CriticalSectionStart()
*//** 
* \b Description:
*
*  This function is used to start a critical section of code.  It disables the
*  global interrupts.
*
* @return 		void
*
* @see Isr_Disable
* @see Isr_Enable
* @see Isr_GlobalStateSet
* @see Isr_GlobalStateGet
* @see Isr_CriticalSectionStart
* @see Isr_CriticalSectionEnd
*
* \b Example Example:
* @code
*    Isr_CriticalSectionStart();
*
*    Tick = Timer_TickGet();
*
*    Isr_CriticalSectionEnd();
* @endcode
*
*  ----------------------
*  - HISTORY OF CHANGES -
*  ----------------------
*    Date    Software Version    Initials   Description 
*  04/01/15       1.0.0            JWB      Function Created.
*
*******************************************************************************/
void Isr_CriticalSectionStart(void)
{
   // TODO:
   // Global ISR disable code goes here
   // TARGET CODE GOES HERE
}

/******************************************************************************
* Function : Isr_CriticalSectionEnd()
*//** 
* \b Description:
*
*  This function is used to end a critical section of code.  It checks the 
*  previous state of the global interrupts and restores that state.  
*
* @return 		void
*
* @see Isr_Disable
* @see Isr_Enable
* @see Isr_GlobalStateSet
* @see Isr_GlobalStateGet
* @see Isr_CriticalSectionStart
* @see Isr_CriticalSectionEnd
*
* \b Example Example:
* @code
*    Isr_CriticalSectionStart();
*
*    Tick = Timer_TickGet();
*
*    Isr_CriticalSectionEnd();
* @endcode
*
*  ----------------------
*  - HISTORY OF CHANGES -
*  ----------------------
*    Date    Software Version    Initials   Description 
*  04/01/15       1.0.0            JWB      Function Created.
*
*******************************************************************************/
void Isr_CriticalSectionEnd(void)
{
   if(IsrState == ISR_ENABLED)
   {
         // TODO:
   	   // Global ISR enable code goes here
   	   // TARGET CODE GOES HERE
   }
}
/*************** END OF FUNCTIONS ***************************************************************************/
