/****************************************************************************
* Title                 :   Interrupt Service Routines
* Filename              :   isr.h
* Author                :   Jacob Beningo (jacob@beningo.com)
* Origin Date           :   04/1/2015
* Version               :   1.0.0
* Compiler              :   COMPILER GOES HERE
* Target                :   MCU TARGET GOES HERE
* Notes                 :   None
*
* THIS SOFTWARE IS PROVIDED BY BENINGO ENGINEERING "AS IS" AND ANY EXPRESSED
* OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL BENINGO ENGINEERING OR ITS CONTRIBUTORS BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
* STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
* IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
* THE POSSIBILITY OF SUCH DAMAGE.
*
*****************************************************************************/
/****************************************************************************
* Doxygen C Template
* Copyright (c) 2013 - Jacob Beningo - All Rights Reserved
*
* Feel free to use this Doxygen Code Template at your own risk for your own
* purposes.  The latest license and updates for this Doxygen C template can be  
* found at www.beningo.com or by contacting Jacob at jacob@beningo.com.
*
* For updates, free software, training and to stay up to date on the latest 
* embedded software techniques sign-up for Jacobs newsletter at 
* http://www.beningo.com/814-2/
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Template. 
*
*****************************************************************************/
/*************** INTERFACE REVISION LOG **************************************
*
*    Date    Version   Author         Description 
*  04/01/15   1.0.0   Jacob Beningo   Interface Created.
*  04/28/2015 1.0.1   Jacob Beningo   Updated IsrStateType to IsrState_t
*									  Removed duplicate interface
*									  Added Isr_GlobalStateSet
*
*****************************************************************************/
/** @file isr.h
 *  @brief This module contains the interface for controlling interrupts.
 */
#ifndef ISR_H_
#define ISR_H_

/******************************************************************************
* Includes
*******************************************************************************/

/******************************************************************************
* Preprocessor Constants
*******************************************************************************/

/******************************************************************************
* Configuration Constants
*******************************************************************************/

/******************************************************************************
* Macros
*******************************************************************************/
	
/******************************************************************************
* Typedefs
*******************************************************************************/
/**
 * This enumeration is a list of test types
 */
typedef enum
{
	ISR_DISABLED,			/**< Global Interrupts Disabled */
	ISR_ENABLED,			/**< Global Interrupts Enabled */
}IsrState_t;

/******************************************************************************
* Variables
*******************************************************************************/


/******************************************************************************
* Function Prototypes
*******************************************************************************/
#ifdef __cplusplus
extern "C"{
#endif

void Isr_Enable(Isr_t IsrIndex);
void Isr_Disable(Isr_t IsrIndex);
void Isr_GlobalStateSet(IsrState_t State);
IsrState_t Isr_GlobalStateGet(void);
void Isr_CriticalSectionStart(void);
void Isr_CriticalSectionEnd(void);

#ifdef __cplusplus
} // extern "C"
#endif

#endif /*ISR_H_*/

/*** End of File **************************************************************/
